@@ -7,23 +7,28 @@ findShortestPath.pl - program finds the shoretst path between two concepts
 
 =head1 SYNOPSIS
 
-This program takes two CUIs and returns the shortest 
+This program takes two terms or CUIs and returns the shortest 
 path between them.
 
 =head1 USAGE
 
-Usage: findShortestPath.pl [OPTIONS] CUI1 CUI2
+Usage: findShortestPath.pl [OPTIONS] TERM1 TERM2
 
 =head1 INPUT
 
 =head2 Required Arguments:
 
-=head3 CUI1 and CUI2
+=head3 TERM1 and TERM2
 
-A concepts (CUIs) from the Unified Medical Language System
+A term in the Unified Medical Language System
 
 =head2 Optional Arguments:
 
+=head3 --cui 
+
+This flag indicates that TERM1 and TERM2 are actual CUIs 
+in the UMLS rather than associated terms
+
 =head3 --username STRING
 
 Username is required to access the umls database on MySql
@@ -111,7 +116,7 @@ this program; if not, write to:
 use UMLS::Interface;
 use Getopt::Long;
 
-GetOptions( "version", "help", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "config=s" );
+GetOptions( "version", "help", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "config=s", "cui" );
 
 
 #  if help is defined, print out help
@@ -182,27 +187,81 @@ else {
 
 &errorCheck($umls);
 
-my $cui1 = shift;
-my $cui2 = shift;
 
-if($umls->validCui($cui1)) {
-    print STDERR "ERROR: The concept ($cui1) is not valid.\n";
-    exit;
+my $input1 = shift;
+my $input2 = shift;
+
+my $flag = "cui";
+
+#  check if the input are CUIs or terms
+if(defined $opt_cui) {
+    push @c1, $input1;
+    push @c2, $input2;
+}
+elsif( ($input1=~/C[0-9]+/) || ($input1=~/C[0-9]+/) ) {
+    
+    print "The input appear to be CUIs. Is this true (y/n)?\n";
+    my $answer = <STDIN>; chomp $answer;
+    if($answer=~/y/) {
+	print "Please specify the --cui option next time.\n";
+	push @c1, $input1;
+	push @c2, $input2;
+    }
+    else {
+	@c1 = $umls->getConceptList($input1); 
+	&errorCheck($umls);
+	@c2 = $umls->getConceptList($input2); 
+	&errorCheck($umls);
+	$flag = "term";
+    }
+}
+else {
+    @c1 = $umls->getConceptList($input1); 
+    &errorCheck($umls);
+    @c2 = $umls->getConceptList($input2); 
+    &errorCheck($umls);
+    $flag = "term";
 }
 
-if($umls->validCui($cui2)) {
-    print STDERR "ERROR: The concept ($cui2) is not valid.\n";
-    exit;
+my $printFlag = 0;
+
+foreach $cui1 (@c1)
+{
+    foreach $cui2 (@c2)
+    {
+
+	if($umls->validCui($cui1)) {
+	    print STDERR "ERROR: The concept ($cui1) is not valid.\n";
+	    exit;
+	}
+
+	if($umls->validCui($cui2)) {
+	    print STDERR "ERROR: The concept ($cui2) is not valid.\n";
+	    exit;
+	}
+	
+	my @shortestpath = $umls->findShortestPath($cui1, $cui2);
+	
+	&errorCheck($umls);
+	
+	if($flag eq "term") {
+	    print "\nThe shortest path between $cui1 ($input1) and $cui2 ($input2):\n";
+	}
+	else {
+	    print "\nThe shortest path between $cui1 and $cui2:\n";
+	}
+	print "  => @shortestpath\n\n";
+
+	$printFlag = 1;
+    }
 }
 
-my @shortestpath = $umls->findShortestPath($cui1, $cui2);
-
-&errorCheck($umls);
-
-print "The shortest path between $cui1 and $cui2:\n";
-print "  => @shortestpath\n";
-
-
+if( !($printFlag) ) {
+    print "\n";
+    print "There is not a path between $input1 and $input2\n";
+    print "given the current view of the UMLS.\n\n";
+}
+	
 sub errorCheck
 {
     my $obj = shift;
@@ -217,7 +276,7 @@ sub errorCheck
 ##############################################################################
 sub minimalUsageNotes {
     
-    print "Usage: findShortestPath.pl [OPTIONS] CUI1 CUI2\n\n";
+    print "Usage: findShortestPath.pl [OPTIONS] TERM1 TERM2\n\n";
     &askHelp();
     exit;
 }
@@ -228,13 +287,16 @@ sub minimalUsageNotes {
 sub showHelp() {
 
         
-    print "This is a utility that takes as input two CUIs\n";
-    print "and returns the shortest path between them.\n\n";
+    print "This is a utility that takes as input two Terms or\n";
+    print "CUIs and returns the shortest path between them.\n\n";
   
-    print "Usage: findShortestPath.pl [OPTIONS] CUI1 CUI2\n\n";
+    print "Usage: findShortestPath.pl [OPTIONS] TERM1 TERM2\n\n";
 
     print "Options:\n\n";
 
+    print "--cui                    Indicates that the input TERM1 and TERM2\n";
+    print "                         are Concept Unique Identifiers (CUIs).\n\n";
+
     print "--username STRING        Username required to access mysql\n\n";
 
     print "--password STRING        Password required to access mysql\n\n";
@@ -256,7 +318,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: findShortestPath.pl,v 1.5 2009/01/12 19:58:45 btmcinnes Exp $';
+    print '$Id: findShortestPath.pl,v 1.6 2009/01/13 22:20:18 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
